@@ -23,6 +23,17 @@ class DataApi:
         self._http_url = 'http://www.gopup.cn/api/v1'
 
     def query(self, api_name, fields='', **kwargs):
+        """
+        # api_name，接口名称；
+        # token，用于识别唯一用户的标识；
+        # params，接口参数，如daily接口中start_date和end_date；
+        # fields，字段列表，用于接口获取指定的字段，以逗号分隔，如"open,high,low,close"；
+
+        :param api_name:
+        :param fields:
+        :param kwargs:
+        :return:
+        """
         req_params = {
             'api_name': api_name,
             'token': self._token,
@@ -33,7 +44,7 @@ class DataApi:
         res = requests.post(self._http_url, json=req_params, timeout=self._timeout, headers={'Connection': 'close'})
         if res:
             result = json.loads(res.text)
-            if result['code'] != 200:
+            if result['error_code'] != 200:
                 raise Exception(result['msg'])
             data = result['data']
             columns = data['fields']
